==> xlniuxdata-vipgame-1.0.62-20160520.074248-7-sources.jar: com/xunlei/niux/data/vipgame/vo/mobilegameapkversion/MobileGameApk.java <==
package com.xunlei.niux.data.vipgame.vo.mobilegameapkversion;

import com.ferret.common.dao.annotation.Table;

@Table(tableName="mobileGameApk",pkFieldName="apkId")
public class MobileGameApk {	

	private Long apkId;
	private String gameId;
	private String apkUrl;
	private String path;
	private String apkName;
	private String packageTime;
	private String apkStatus;
	private String testRemark;
	private String testUser;
	private String testTime;
	private String submitTestRemark;
	private String muliPhotoUrl;
	private Integer packageType;
	private Integer isWDJGame;
	private Integer isForceUpdate;  //是否设为强更
	private Integer canForceUpdate; //是否支持强更

	public Integer getPackageType() {
		return packageType;
	}
	public void setPackageType(Integer packageType) {
		this.packageType = packageType;
	}
	public String getMuliPhotoUrl() {
		return muliPhotoUrl;
	}
	public void setMuliPhotoUrl(String muliPhotoUrl) {
		this.muliPhotoUrl = muliPhotoUrl;
	}
	public String getPath() {
		return path;
	}
	public void setPath(String path) {
		this.path = path;
	}
	public String getApkUrl() {
		return apkUrl;
	}
	public void setApkUrl(String apkUrl) {
		this.apkUrl = apkUrl;
	}
	public Long getApkId() {
		return apkId;
	}
	public void setApkId(Long apkId) {
		this.apkId = apkId;
	}
	public String getGameId() {
		return gameId;
	}
	public void setGameId(String gameId) {
		this.gameId = gameId;
	}
	public String getApkName() {
		return apkName;
	}
	public void setApkName(String apkName) {
		this.apkName = apkName;
	}
	public String getPackageTime() {
		return packageTime;
	}
	public void setPackageTime(String packageTime) {
		this.packageTime = packageTime;
	}
	public String getApkStatus() {
		return apkStatus;
	}
	public void setApkStatus(String apkStatus) {
		this.apkStatus = apkStatus;
	}
	public String getTestRemark() {
		return testRemark;
	}
	public void setTestRemark(String testRemark) {
		this.testRemark = testRemark;
	}
	public String getTestUser() {
		return testUser;
	}
	public void setTestUser(String testUser) {
		this.testUser = testUser;
	}
	public String getTestTime() {
		return testTime;
	}
	public void setTestTime(String testTime) {
		this.testTime = testTime;
	}
	public String getSubmitTestRemark() {
		return submitTestRemark;
	}
	public void setSubmitTestRemark(String submitTestRemark) {
		this.submitTestRemark = submitTestRemark;
	}

	public Integer getIsWDJGame() {
		return isWDJGame;
	}

	public void setIsWDJGame(Integer isWDJGame) {
		this.isWDJGame = isWDJGame;
	}

    public Integer getIsForceUpdate(){
        return isForceUpdate;
    }

    public void setIsForceUpdate(Integer isForceUpdate){
        this.isForceUpdate = isForceUpdate;
    }

    public Integer getCanForceUpdate(){
        return canForceUpdate;
    }

    public void setCanForceUpdate(Integer canForceUpdate){
        this.canForceUpdate = canForceUpdate;
    }
}

==> xlniuxdata-vipgame-1.0.65-20160825.104143-53-sources.jar: com/xunlei/niux/data/vipgame/vo/mobilegameapkversion/MobileGameApk.java <==
package com.xunlei.niux.data.vipgame.vo.mobilegameapkversion;

import com.ferret.common.dao.annotation.Table;

@Table(tableName="mobileGameApk",pkFieldName="apkId")
public class MobileGameApk {	

	private Long apkId;
	private String gameId;
	private String apkUrl;
	private String path;
	private String apkName;
	private String packageTime;
	private String apkStatus;
	private String testRemark;
	private String testUser;
	private String testTime;
	private String submitTestRemark;
	private String muliPhotoUrl;
	private Integer packageType;
	private Integer isWDJGame;
	private Integer isForceUpdate;  //是否设为强更
	private Integer canForceUpdate; //是否支持强更
	private String sdkVersion; //sdk版本号

	public Integer getPackageType() {
		return packageType;
	}
	public void setPackageType(Integer packageType) {
		this.packageType = packageType;
	}
	public String getMuliPhotoUrl() {
		return muliPhotoUrl;
	}
	public void setMuliPhotoUrl(String muliPhotoUrl) {
		this.muliPhotoUrl = muliPhotoUrl;
	}
	public String getPath() {
		return path;
	}
	public void setPath(String path) {
		this.path = path;
	}
	public String getApkUrl() {
		return apkUrl;
	}
	public void setApkUrl(String apkUrl) {
		this.apkUrl = apkUrl;
	}
	public Long getApkId() {
		return apkId;
	}
	public void setApkId(Long apkId) {
		this.apkId = apkId;
	}
	public String getGameId() {
		return gameId;
	}
	public void setGameId(String gameId) {
		this.gameId = gameId;
	}
	public String getApkName() {
		return apkName;
	}
	public void setApkName(String apkName) {
		this.apkName = apkName;
	}
	public String getPackageTime() {
		return packageTime;
	}
	public void setPackageTime(String packageTime) {
		this.packageTime = packageTime;
	}
	public String getApkStatus() {
		return apkStatus;
	}
	public void setApkStatus(String apkStatus) {
		this.apkStatus = apkStatus;
	}
	public String getTestRemark() {
		return testRemark;
	}
	public void setTestRemark(String testRemark) {
		this.testRemark = testRemark;
	}
	public String getTestUser() {
		return testUser;
	}
	public void setTestUser(String testUser) {
		this.testUser = testUser;
	}
	public String getTestTime() {
		return testTime;
	}
	public void setTestTime(String testTime) {
		this.testTime = testTime;
	}
	public String getSubmitTestRemark() {
		return submitTestRemark;
	}
	public void setSubmitTestRemark(String submitTestRemark) {
		this.submitTestRemark = submitTestRemark;
	}

	public Integer getIsWDJGame() {
		return isWDJGame;
	}

	public void setIsWDJGame(Integer isWDJGame) {
		this.isWDJGame = isWDJGame;
	}

    public Integer getIsForceUpdate(){
        return isForceUpdate;
    }

    public void setIsForceUpdate(Integer isForceUpdate){
        this.isForceUpdate = isForceUpdate;
    }

    public Integer getCanForceUpdate(){
        return canForceUpdate;
    }

    public void setCanForceUpdate(Integer canForceUpdate){
        this.canForceUpdate = canForceUpdate;
    }

    public String getSdkVersion(){
        return sdkVersion;
    }

    public void setSdkVersion(String sdkVersion){
        this.sdkVersion = sdkVersion;
    }
}
